module.exports = defineTest({
	description: 'renames function expression IDs correctly'
});
